@@ -95,7 +95,7 @@ from ._open import open  # pylint: disable=redefined-builtin
 # Export some more APIs originally from other sub modules.
 from ..backend import ParserT
 from ..common import (
-    IOInfo, InDataT, InDataExT,
+    InDataT, InDataExT,
     UnknownFileTypeError, UnknownParserTypeError,
     UnknownProcessorTypeError, ValidationError
 )
@@ -103,6 +103,9 @@ from ..dicts import (
     MS_REPLACE, MS_NO_REPLACE, MS_DICTS, MS_DICTS_AND_LISTS, MERGE_STRATEGIES,
     merge, get, set_,
 )
+from ..ioinfo import (
+    IOInfo, make as ioinfo_make, makes as ioinfo_makes,
+)
 from ..parsers import (
     load_plugins, list_types, list_by_cid, list_by_type, list_by_extension,
     findall, find, MaybeParserT
@@ -113,7 +116,7 @@ from ..schema import (
 )
 
 
-__version__ = '0.11.1'
+__version__ = '0.12.0'
 
 
 def version():
@@ -133,7 +136,7 @@ __all__ = [
     'ParserT',
 
     # anyconfig.common
-    'IOInfo', 'InDataT', 'InDataExT',
+    'InDataT', 'InDataExT',
     'UnknownFileTypeError', 'UnknownParserTypeError',
     'UnknownProcessorTypeError', 'ValidationError',
 
@@ -142,6 +145,9 @@ __all__ = [
     'MERGE_STRATEGIES',
     'merge', 'get', 'set_',
 
+    # anyconfig.ioinfo
+    'IOInfo', 'ioinfo_make', 'ioinfo_makes',
+
     # anyconfig.parsers
     'load_plugins', 'list_types', 'list_by_cid', 'list_by_type',
     'list_by_extension', 'findall', 'find',
