@@ -7,9 +7,11 @@ r"""Utility functions in anyconfig.backend.base.
 import typing
 
 from ...common import (
-    InDataT, IOInfo, PathOrIOInfoT, InDataExT
+    InDataT, InDataExT
+)
+from ...ioinfo import (
+    IOInfo, PathOrIOInfoT
 )
-
 
 OutDataExT = InDataExT
 
