@@ -20,11 +20,14 @@ pathlib.Path and io objects.
   attributes like input and output type (path, stream or pathlib.Path object),
   path, opener, etc.
 """
-from .factory import make
-from .paths import expand_paths
+from .datatypes import IOInfo, PathOrIOInfoT
+from .detectors import is_stream
+from .factory import make, makes
 
 __all__ = [
-    'make', 'expand_paths'
+    'IOInfo', 'PathOrIOInfoT',
+    'is_stream',
+    'make', 'makes',
 ]
 
 # vim:sw=4:ts=4:et:
