@@ -1,6 +1,5 @@
 #
-# Copyright (C) 2018 Satoru SATOH <ssato@redhat.com>
-# Copyright (C) 2019 - 2020 Satoru SATOH <satoru.satoh@gmail.com>
+# Copyright (C) 2018 - 2021 Satoru SATOH <satoru.satoh@gmail.com>
 # SPDX-License-Identifier: MIT
 #
 r"""Abstract processor module.
@@ -9,7 +8,7 @@ r"""Abstract processor module.
 
    - Add to abstract processors such like Parsers (loaders and dumpers).
 """
-from __future__ import absolute_import
+import typing
 
 
 class Processor:
@@ -25,42 +24,47 @@ class Processor:
        This class ifself is not a singleton but its children classes should so
        in most cases, I think.
     """
-    _cid = None
-    _type = None
-    _priority = 0   # 0 (lowest priority) .. 99  (highest priority)
-    _extensions = []
+    _cid: str = ''
+    _type: str = ''
+    _priority: int = 0   # 0 (lowest priority) .. 99  (highest priority)
+    _extensions: typing.List[str] = []
 
     @classmethod
-    def cid(cls):
-        """Processor class ID
+    def cid(cls) -> str:
+        """Processor class ID.
         """
-        return repr(cls) if getattr(cls, "_cid", None) is None else cls._cid
+        return cls._cid
 
     @classmethod
-    def type(cls):
-        """Processors' type
+    def type(cls) -> str:
+        """Processors' type.
         """
-        return cls._type
+        return str(cls._type)
 
     @classmethod
-    def priority(cls):
-        """Processors's priority
+    def priority(cls) -> int:
+        """Processors's priority.
         """
         return cls._priority
 
     @classmethod
-    def extensions(cls):
+    def extensions(cls) -> typing.List[str]:
         """A list of file extensions of files which this process can process.
         """
         return cls._extensions
 
     @classmethod
-    def __eq__(cls, other):
+    def __eq__(cls, other) -> bool:
+        """Test equality.
+        """
         return cls.cid() == other.cid()
 
-    def __str__(self):
-        return ("<Processor cid=%s, type=%s, prio=%d, "
-                "extensions=%r" % (self.cid(), self.type(), self.priority(),
-                                   self.extensions()))
+    def __str__(self) -> str:
+        """A string repr.
+        """
+        return (
+            f'<Processor cid={self.cid()}, type={self.type()}, '
+            f'prio={self.priority()}, extensions={self.extensions()!r}'
+        )
 
 # vim:sw=4:ts=4:et:
