@@ -14,9 +14,7 @@ instances.
    - Add to abstract processors such like Parsers (loaders and dumpers).
 """
 from .detectors import (
-    is_iterable, is_path, is_path_obj, is_ioinfo,
-    is_stream_ioinfo, is_path_like_object, is_paths,
-    is_dict_like, is_list_like
+    is_iterable, is_dict_like, is_list_like
 )
 from .files import get_path_from_stream
 from .lists import (
@@ -28,9 +26,7 @@ from .utils import (
 
 
 __all__ = [
-    'is_iterable', 'is_path', 'is_path_obj', 'is_ioinfo',
-    'is_stream_ioinfo', 'is_path_like_object', 'is_paths',
-    'is_dict_like', 'is_list_like',
+    'is_iterable', 'is_dict_like', 'is_list_like',
     'get_path_from_stream',
     'groupby', 'concat',
     'filter_options', 'noop',
