@@ -6,17 +6,17 @@ r"""Common test Utility functions, constants and global variables, etc.
 """
 from .constants import TESTS_DIR, RES_DIR, NULL_CNTNR
 from .collector import TDataCollector
-from .datatypes import TDataPaths, TData
+from .datatypes import TData
 from .utils import (
-    load_data, each_data_from_dir, maybe_data_path
+    load_data, load_datasets_from_dir, maybe_data_path
 )
 
 
 __all__ = [
     'TESTS_DIR', 'RES_DIR', 'NULL_CNTNR',
     'TDataCollector',
-    'TDataPaths', 'TData',
-    'load_data', 'each_data_from_dir', 'maybe_data_path'
+    'TData',
+    'load_data', 'load_datasets_from_dir', 'maybe_data_path'
 ]
 
 # vim:sw=4:ts=4:et:
