@@ -3,11 +3,13 @@
 # SPDX-License-Identifier: MIT
 #
 # pylint: disable=missing-docstring, invalid-name
+"""Test cases for anyconfig.ioinfo.factory.
+"""
 import unittest
 
 import anyconfig.ioinfo.factory as TT
 
-from anyconfig.common import (
+from anyconfig.ioinfo.datatypes import (
     IOInfo, IOI_PATH_OBJ, IOI_STREAM
 )
 
